//
//  CHFileManagerExtensions.h
//  POBase
//
//  Created by Pieter Omvlee on 3/9/08.
//  Copyright 2008 Bohemian Coding. All rights reserved.
//

#import <Cocoa/Cocoa.h>

#import "CHStringExtensions.h"

/*!
 * @header CHFileManagerExtensions
 * A way to browse through sub-directories a bit more easily
 */
@interface NSFileManager (CHFileManagerExtensions)

/*!
 * @method visibleSubpathsOfDirectory
 * @param path the directory to search
 * Equal to subpathsOfDirectory but leaves out the invisible files
 */
- (NSArray *)visibleSubpathsOfDirectory:(NSString *)path;

/*!
 * @method visibleSubpathsOfDirectory
 * @param paths an array of paths
 * Calls visibleSubpathsOfDirectory for each object in paths
 */
- (NSArray *)visibleSubpathsOfDirectories:(NSArray *)paths;

/*!
 * @method createDirectoryIfNecessary
 * @param directory the directory to create
 * If the directory exists, this method does nothing. If it doesnt, the directory is created.
 */
- (BOOL)createDirectoryIfNecessary:(NSString *)directory;

- (NSArray *)visibleSubpathsOfDirectoryWithoutGoingIntoPackages:(NSString *)path;
- (NSArray *)shallowSubpathsOfDirectory:(NSString *)path;

- (BOOL)fileIsFolder:(NSString *)path;

@end
